@@ -1,4 +1,4 @@
-/* xml++.cc
+/* contentnode.cc
  * libxml++ and this file are copyright (C) 2000 by Ari Johnson, and
  * are covered by the GNU Lesser General Public License, which should be
  * included with libxml++ as the file COPYING.
@@ -19,18 +19,31 @@ ContentNode::ContentNode(xmlNode* node)
 ContentNode::~ContentNode()
 {}
 
-std::string ContentNode::get_content() const
+Glib::ustring ContentNode::get_content() const
 {
   if(cobj()->type == XML_ELEMENT_NODE)
+  {
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("this node type doesn't have content");
+    #else
+    return Glib::ustring();
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
+  }
 
   return cobj()->content ? (char*)cobj()->content : "";
 }
 
-void ContentNode::set_content(const std::string& content)
+void ContentNode::set_content(const Glib::ustring& content)
 {
    if(cobj()->type == XML_ELEMENT_NODE)
-      throw internal_error("can't set content for this node type");
+   {
+     #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
+     throw internal_error("can't set content for this node type");
+     #else
+     return;
+     #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
+   }
+      
 
    xmlNodeSetContent(cobj(), (xmlChar*)content.c_str());
 }
